#Hello BMS2 Section B,

#First, note that the '#' symbol causes all of the text that follows it on a given line makes that text invisible to R.
#In other words, if you were to copy and paste the contents of this file into R, I woudl ignore all teh text that follows a # on a line.

#This file demonstrates how to automate a randomiation test.
#Please feel free to use it in your own work.  But, to do so, you 'll need to understand what you're doing and alter the file, accordingly.

#First, import the data:
data <- read.table("/Users/crispinjordan/Desktop/9Nov-1.csv",header=TRUE,sep=",")

#Now, create a new dataframe with the data in oder with respect to gender:
data.ordered <- data[order(data$Gender),]

#Note that within 'data.ordered', the female forearm lengths lie on lines 1 to 24, and the male data are at 25 to 31.
#With this in mind, calaculate the average forearm lengths for females and males:
femAvg <- mean(data.ordered[1:30,"Forearm"])
maleAvg <- mean(data.ordered[31:36,"Forearm"])

#, now you can calculate the difference between them, and storethe absolute value of this difference in 'observed.diff':
observed.diff <- abs(femAvg-maleAvg)
#You can look at the difference like this:
observed.diff
#[1] 20.69643


#Here comes the code to automate the randomization test.
#This file will NOT explain all of the functions in detail; I leave some of that up to you, using the resources you have
#learned from the R Sessions (e.g., using rseek.org).  My sense if that you will learn more this way.

#First, create a vector that contains nothing.  We'll use this empty vector, called diffs, to store the randomized differences:
diffs <- c(NULL)

#This next section is called a 'for loop';  for loops are used when you want to execute some commands repeatedly, a certain number of times.
#The commands that will be executed multiple times are contined between the braces, { and }
#This for loop will exectute commands between these braces 2000 times:
for (i in 1:2000) {

#As we did in the practical, we create a new column that will hold the randomly shuffled forearm lengths.
#Note, however, that we always re-create the same column ('rand') every time we run this command (all 2000 times).
#This means that each time we run the command, we simply over-write the datathat was stored in 'rand' in the previous run.
#(This saved some computer memory and makes the coding simpler, by not storing the randomizations in 2000 separate columns)
data.ordered$rand <- sample(data.ordered[,"Forearm"],nrow(data.ordered),replace=FALSE)

#Now, we calculate the female and male average forearm lengths for the randomized data.  NOTE that the rows are correctly specified for each gender
femAvg.rand <- mean(data.ordered[1:30,"rand"])
maleAvg.rand <- mean(data.ordered[31:36,"rand"])

#Now, we calculate the differences between the random differences, and calculate the absolute value (using abs())
rand.diff <- abs(femAvg.rand-maleAvg.rand)

#Now, we add the value of rand.diff to the vector, diffs, using the function append().  By the end of this analysis, diffs will contain 2000 values of rand.diff:
diffs <- append(diffs,rand.diff)

}

#We're now outside of the 'for loop', so the following commands will only be executed once:
#As in the practical, you can calculate the p-value by sorting the random differences, and determining what fraction of those differences are greater than
diffs.sorted <- sort(diffs)
#Now, look at the sorted differences between the average female and male foreatrm lengths for the randomized data:
diffs.sorted


#Or, we can let R so some of our work to determine the p-value:

#First, make a vector of zeros; the vector has as many values as there were randomizations
#We will over-write some of these zeros, below.
zeros <- rep.int(0,2000)
#Now, combine the vectors, diffs and zeros, using the cbind() function (cbind() combines data into different columns; what do you think rbind() does?)
diffs <- cbind(diffs,zeros)

#We now use the function ifelse() to ask whether each of the random differences in the column that held the rand.diff data is less than the observed
#difference; if it is, then keep the value in the 2nd column (which holds the zeros) as zero, but if it is not (i.e., if the random difference is
#greater than the observed difference) then replace the zero with a 1.
#Overall, this code provides us with a way of marking every instance where the random difference is greater than the observed difference with a 1.
#Therefore, is we sum all of these 1's, we get a count of the number of times that the random difference exceeded the observed one.
diffs[,2] <- ifelse(diffs[,1] < observed.diff,0,1)

#Now, sum the 1's (i.e., all the times that the random difference exceeded the observed one)
sum(diffs[,2])

#We calculate a p-value by dividing this sum by the number of randomizations that occurred.
#The number of randomizations simply equals the number of rows in diffs (each row contains data from one randomization).
sum(diffs[,2])/nrow(diffs)

#This is your p-value.